@@ -1,10 +1,5 @@
 package App::shcompgen;
 
-our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2020-04-03'; # DATE
-our $DIST = 'App-shcompgen'; # DIST
-our $VERSION = '0.322'; # VERSION
-
 use 5.010001;
 use strict;
 use warnings;
@@ -14,6 +9,11 @@ use File::Slurper qw(read_text write_text);
 use Perinci::Object;
 use Perinci::Sub::Util qw(err);
 
+our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
+our $DATE = '2022-08-10'; # DATE
+our $DIST = 'App-shcompgen'; # DIST
+our $VERSION = '0.323'; # VERSION
+
 our %SPEC;
 
 my $re_progname = qr/\A[A-Za-z0-9_.,:-]+\z/;
@@ -284,7 +284,7 @@ sub _gen_completion_script {
             "#!$^X\n",
             "use Getopt::Long::Complete;\n",
             "my \$spec = ", Data::Dmp::dmp($dump_res->[2]), ";\n",
-            "GetOptions(%\$spec);\n",
+            "GetOptions(\@\$spec);\n",
         );
         $comp = ($args{global} ?
                      $args{helper_global_dir} : $args{helper_per_user_dir}) .
@@ -1128,7 +1128,7 @@ _
                 my $word = $args{word} // '';
 
                 my $res = list($args{args});
-                return undef unless $res->[0] == 200;
+                return unless $res->[0] == 200;
                 Complete::Util::complete_array_elem(
                     array=>$res->[2], word=>$word);
             },
@@ -1156,7 +1156,7 @@ App::shcompgen - Generate shell completion scripts
 
 =head1 VERSION
 
-This document describes version 0.322 of App::shcompgen (from Perl distribution App-shcompgen), released on 2020-04-03.
+This document describes version 0.323 of App::shcompgen (from Perl distribution App-shcompgen), released on 2022-08-10.
 
 =head1 FUNCTIONS
 
@@ -1165,7 +1165,7 @@ This document describes version 0.322 of App::shcompgen (from Perl distribution
 
 Usage:
 
- detect_prog(%args) -> [status, msg, payload, meta]
+ detect_prog(%args) -> [$status_code, $reason, $payload, \%result_meta]
 
 Detect a program.
 
@@ -1186,12 +1186,12 @@ Override guessing and select shell manually.
 
 Returns an enveloped result (an array).
 
-First element (status) is an integer containing HTTP status code
+First element ($status_code) is an integer containing HTTP-like status code
 (200 means OK, 4xx caller error, 5xx function error). Second element
-(msg) is a string containing error message, or 'OK' if status is
-200. Third element (payload) is optional, the actual result. Fourth
-element (meta) is called result metadata and is optional, a hash
-that contains extra information.
+($reason) is a string containing error message, or something like "OK" if status is
+200. Third element ($payload) is the actual result, but usually not present when enveloped result is an error response ($status_code is not 2xx). Fourth
+element (%result_meta) is called result metadata and is optional, a hash
+that contains extra information, much like how HTTP response headers provide additional metadata.
 
 Return value:  (any)
 
@@ -1201,7 +1201,7 @@ Return value:  (any)
 
 Usage:
 
- generate(%args) -> [status, msg, payload, meta]
+ generate(%args) -> [$status_code, $reason, $payload, \%result_meta]
 
 Generate shell completion scripts for detectable programs.
 
@@ -1308,12 +1308,12 @@ Directory to put completions scripts.
 
 Returns an enveloped result (an array).
 
-First element (status) is an integer containing HTTP status code
+First element ($status_code) is an integer containing HTTP-like status code
 (200 means OK, 4xx caller error, 5xx function error). Second element
-(msg) is a string containing error message, or 'OK' if status is
-200. Third element (payload) is optional, the actual result. Fourth
-element (meta) is called result metadata and is optional, a hash
-that contains extra information.
+($reason) is a string containing error message, or something like "OK" if status is
+200. Third element ($payload) is the actual result, but usually not present when enveloped result is an error response ($status_code is not 2xx). Fourth
+element (%result_meta) is called result metadata and is optional, a hash
+that contains extra information, much like how HTTP response headers provide additional metadata.
 
 Return value:  (any)
 
@@ -1323,7 +1323,7 @@ Return value:  (any)
 
 Usage:
 
- guess_shell() -> [status, msg, payload, meta]
+ guess_shell() -> [$status_code, $reason, $payload, \%result_meta]
 
 Guess running shell.
 
@@ -1333,12 +1333,12 @@ No arguments.
 
 Returns an enveloped result (an array).
 
-First element (status) is an integer containing HTTP status code
+First element ($status_code) is an integer containing HTTP-like status code
 (200 means OK, 4xx caller error, 5xx function error). Second element
-(msg) is a string containing error message, or 'OK' if status is
-200. Third element (payload) is optional, the actual result. Fourth
-element (meta) is called result metadata and is optional, a hash
-that contains extra information.
+($reason) is a string containing error message, or something like "OK" if status is
+200. Third element ($payload) is the actual result, but usually not present when enveloped result is an error response ($status_code is not 2xx). Fourth
+element (%result_meta) is called result metadata and is optional, a hash
+that contains extra information, much like how HTTP response headers provide additional metadata.
 
 Return value:  (any)
 
@@ -1348,7 +1348,7 @@ Return value:  (any)
 
 Usage:
 
- init(%args) -> [status, msg, payload, meta]
+ init(%args) -> [$status_code, $reason, $payload, \%result_meta]
 
 Initialize shcompgen.
 
@@ -1433,12 +1433,12 @@ Directory to put completions scripts.
 
 Returns an enveloped result (an array).
 
-First element (status) is an integer containing HTTP status code
+First element ($status_code) is an integer containing HTTP-like status code
 (200 means OK, 4xx caller error, 5xx function error). Second element
-(msg) is a string containing error message, or 'OK' if status is
-200. Third element (payload) is optional, the actual result. Fourth
-element (meta) is called result metadata and is optional, a hash
-that contains extra information.
+($reason) is a string containing error message, or something like "OK" if status is
+200. Third element ($payload) is the actual result, but usually not present when enveloped result is an error response ($status_code is not 2xx). Fourth
+element (%result_meta) is called result metadata and is optional, a hash
+that contains extra information, much like how HTTP response headers provide additional metadata.
 
 Return value:  (any)
 
@@ -1448,7 +1448,7 @@ Return value:  (any)
 
 Usage:
 
- list(%args) -> [status, msg, payload, meta]
+ list(%args) -> [$status_code, $reason, $payload, \%result_meta]
 
 List all shell completion scripts generated by this script.
 
@@ -1532,12 +1532,12 @@ Directory to put completions scripts.
 
 Returns an enveloped result (an array).
 
-First element (status) is an integer containing HTTP status code
+First element ($status_code) is an integer containing HTTP-like status code
 (200 means OK, 4xx caller error, 5xx function error). Second element
-(msg) is a string containing error message, or 'OK' if status is
-200. Third element (payload) is optional, the actual result. Fourth
-element (meta) is called result metadata and is optional, a hash
-that contains extra information.
+($reason) is a string containing error message, or something like "OK" if status is
+200. Third element ($payload) is the actual result, but usually not present when enveloped result is an error response ($status_code is not 2xx). Fourth
+element (%result_meta) is called result metadata and is optional, a hash
+that contains extra information, much like how HTTP response headers provide additional metadata.
 
 Return value:  (any)
 
@@ -1547,7 +1547,7 @@ Return value:  (any)
 
 Usage:
 
- remove(%args) -> [status, msg, payload, meta]
+ remove(%args) -> [$status_code, $reason, $payload, \%result_meta]
 
 Remove shell completion scripts generated by this script.
 
@@ -1636,12 +1636,12 @@ Directory to put completions scripts.
 
 Returns an enveloped result (an array).
 
-First element (status) is an integer containing HTTP status code
+First element ($status_code) is an integer containing HTTP-like status code
 (200 means OK, 4xx caller error, 5xx function error). Second element
-(msg) is a string containing error message, or 'OK' if status is
-200. Third element (payload) is optional, the actual result. Fourth
-element (meta) is called result metadata and is optional, a hash
-that contains extra information.
+($reason) is a string containing error message, or something like "OK" if status is
+200. Third element ($payload) is the actual result, but usually not present when enveloped result is an error response ($status_code is not 2xx). Fourth
+element (%result_meta) is called result metadata and is optional, a hash
+that contains extra information, much like how HTTP response headers provide additional metadata.
 
 Return value:  (any)
 
@@ -1653,6 +1653,35 @@ Please visit the project's homepage at L<https://metacpan.org/release/App-shcomp
 
 Source repository is at L<https://github.com/perlancar/perl-App-shcompgen>.
 
+=head1 AUTHOR
+
+perlancar <perlancar@cpan.org>
+
+=head1 CONTRIBUTING
+
+
+To contribute, you can send patches by email/via RT, or send pull requests on
+GitHub.
+
+Most of the time, you don't need to build the distribution yourself. You can
+simply modify the code, then test via:
+
+ % prove -l
+
+If you want to build the distribution (e.g. to try to install it locally on your
+system), you can install L<Dist::Zilla>,
+L<Dist::Zilla::PluginBundle::Author::PERLANCAR>,
+L<Pod::Weaver::PluginBundle::Author::PERLANCAR>, and sometimes one or two other
+Dist::Zilla- and/or Pod::Weaver plugins. Any additional steps required beyond
+that are considered a bug and can be reported to me.
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2022, 2020, 2018, 2017, 2016, 2015, 2014 by perlancar <perlancar@cpan.org>.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
 =head1 BUGS
 
 Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=App-shcompgen>
@@ -1661,15 +1690,4 @@ When submitting a bug or request, please include a test-file or a
 patch to an existing test-file that illustrates the bug or desired
 feature.
 
-=head1 AUTHOR
-
-perlancar <perlancar@cpan.org>
-
-=head1 COPYRIGHT AND LICENSE
-
-This software is copyright (c) 2020, 2018, 2017, 2016, 2015, 2014 by perlancar@cpan.org.
-
-This is free software; you can redistribute it and/or modify it under
-the same terms as the Perl 5 programming language system itself.
-
 =cut
